==> jdbacl-0.6.4-sources.jar: org/databene/jdbacl/model/AbstractDBTableComponent.java <==
/*
 * (c) Copyright 2010 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License (GPL).
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.jdbacl.model;

/**
 * Parent class for classes that represent a sub {@link DBObject} of a {@link DBTable}.<br/><br/>
 * Created: 28.11.2010 11:58:44
 * @since 0.6.4
 * @author Volker Bergmann
 */
public abstract class AbstractDBTableComponent extends AbstractDBObject implements DBTableComponent {

	private static final long serialVersionUID = 3009611143703482138L;

	public AbstractDBTableComponent(String name) {
		this(name, null);
	}
	
	public AbstractDBTableComponent(String name, DBTable owner) {
		super(name, owner);
	}

    public DBTable getTable() {
        return (DBTable) getOwner();
    }

    public void setTable(DBTable table) {
        setOwner(table);
    }

}

==> jdbacl-0.8.3-sources.jar: org/databene/jdbacl/model/AbstractDBTableComponent.java <==
/*
 * (c) Copyright 2010-2011 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License (GPL).
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.jdbacl.model;

/**
 * Parent class for classes that represent a sub {@link DBObject} of a {@link DBTable}.<br/><br/>
 * Created: 28.11.2010 11:58:44
 * @since 0.6.4
 * @author Volker Bergmann
 */
public abstract class AbstractDBTableComponent extends AbstractDBObject implements DBTableComponent {

	private static final long serialVersionUID = 3009611143703482138L;

	public AbstractDBTableComponent(String name, String type) {
		this(name, type, null);
	}
	
	public AbstractDBTableComponent(String name, String type, DBTable owner) {
		super(name, type, owner);
	}

    public DBTable getTable() {
        return (DBTable) getOwner();
    }

    public void setTable(DBTable table) {
        setOwner(table);
    }

}
